FluttyAvatarUtils class
Represents a FluttyAvatarUtils.
This class belongs to the components library and is designed to be easy to read and extend. Use it to compose higher‑level behaviors while keeping responsibilities well‑scoped.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculateInnerRadius(
BorderRadius outer, double padding, double borderWidth) → BorderRadius - Calculates the inner border radius after accounting for padding and border width.
-
generateAccessibleColor(
String name) → Color -
Executes
generate Accessible Color. -
getInitials(
String name) → String -
Executes
get Initials.