FluttyThumbShape class
Represents a FluttyThumbShape.
This class belongs to the components library and is designed to be easy to read and extend. Use it to compose higher‑level behaviors while keeping responsibilities well‑scoped.
- Inheritance
-
- Object
- SliderComponentShape
- FluttyThumbShape
Constructors
- FluttyThumbShape({required Color borderColor, double thumbRadius = 14.0, double borderWidth = 3.0})
-
Creates a FluttyThumbShape.
const
Properties
- borderColor → Color
-
Exposes
border Color.final - borderWidth → double
-
Exposes
border Width.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbRadius → double
-
Exposes
thumb Radius.final
Methods
-
getPreferredSize(
bool isEnabled, bool isDiscrete) → Size -
Executes
get Preferred Size.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset center, {required Animation< double> activationAnimation, required Animation<double> enableAnimation, required bool isDiscrete, required TextPainter labelPainter, required RenderBox parentBox, required SliderThemeData sliderTheme, required TextDirection textDirection, required double value, required double textScaleFactor, required Size sizeWithOverflow}) → void -
Paints the shape, taking into account the state passed to it.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited