FluttyUser class
Represents a FluttyUser.
This class belongs to the components library and is designed to be easy to read and extend. Use it to compose higher‑level behaviors while keeping responsibilities well‑scoped.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FluttyUser
Constructors
- FluttyUser({required String username, required FluttyAvatarProps avatarProps, Key? key, String? description, TextStyle? usernameStyle, TextStyle? descriptionStyle, UserInfoPosition infoPosition = UserInfoPosition.right, VoidCallback? onTap, SpacingVariant gap = SpacingVariant.sm})
-
Creates a FluttyUser widget.
const
Properties
- avatarProps → FluttyAvatarProps
-
Exposes
avatar Props.final - description → String?
-
Exposes
description.final - descriptionStyle → TextStyle?
-
Exposes
description Style.final - gap → SpacingVariant
-
Exposes
gap.final - hashCode → int
-
The hash code for this object.
no setterinherited
- infoPosition → UserInfoPosition
-
Exposes
info Position.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
Exposes
on Tap.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → String
-
Exposes
username.final - usernameStyle → TextStyle?
-
Exposes
username Style.final
Methods
-
build(
BuildContext context) → Widget -
Executes
build.override -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited